pub struct Handout<'a, P: Pixel, U: GenericImage<Pixel = P>> { /* private fields */ }Expand description
Represents a handout of an image cell. This struct is used to write to the image cell’s underlying image’s data buffer without a mutable reference to the underlying image.
Implementations
Sourceimpl<'a, P: Pixel, U: GenericImage<Pixel = P>> Handout<'a, P, U>
impl<'a, P: Pixel, U: GenericImage<Pixel = P>> Handout<'a, P, U>
Sourcepub unsafe fn unsafe_put_pixel(&mut self, pixel: P)
pub unsafe fn unsafe_put_pixel(&mut self, pixel: P)