pub struct ImageCell<P: Pixel, U: GenericImage<Pixel = P>> { /* private fields */ }Expand description
A struct that allows multible mutable references to an underlying image’s data buffer. This is an unsafe struct and should only be used when no two items are trying to change the same place in the underlying image’s data buffer. This struct is used to allow multible threads to write to the same image at the same time.
Implementations
Sourceimpl<P: Pixel, U: GenericImage<Pixel = P>> ImageCell<P, U>
impl<P: Pixel, U: GenericImage<Pixel = P>> ImageCell<P, U>
pub fn new(image: Image<P, U>) -> Self
Sourcepub fn into_inner(self) -> Image<P, U>
pub fn into_inner(self) -> Image<P, U>
Returns the underlying image.
Sourcepub unsafe fn request_handout(&self, x: u32, y: u32) -> Handout<'_, P, U>
pub unsafe fn request_handout(&self, x: u32, y: u32) -> Handout<'_, P, U>
Requests a handout at the given coordinates of the undelrying image. Can be be used to write to an underlying image buffer across threads without a mutable reference to the underlying image.
Safety
This function is unsafe because it does not implement any thread safety via locks or anything else. It is up to the caller to ensure that no two threads are trying to write to the same place in the underlying image’s data buffer.
Arguments
x- The x coordinate of the pixel to request a handout for.y- The y coordinate of the pixel to request a handout for.
Returns
A handout that can be used to write to the underlying image’s data buffer.
Example
use image_merger::{Rgb, raw::ImageCell, Image};
use image::ImageBuffer;
let buf: ImageBuffer<Rgb<u8>, Vec<u8>> = ImageBuffer::new(100, 100);
let cell = ImageCell::new(Image::from(buf));
let mut handout = unsafe { cell.request_handout(0, 0) };
handout.put_pixel(Rgb([255, 255, 255]));Trait Implementations
impl<P: Pixel, U: GenericImage<Pixel = P>> Send for ImageCell<P, U>
impl<P: Pixel, U: GenericImage<Pixel = P>> Sync for ImageCell<P, U>